/******************************************************************************
* This Program is the Confidential and Proprietary product of Altera Corp.    *
* Any unauthorized use,  reproduction or transfer of this program is strictly *
* prohibited. Copyright (c)  1994  by Altera Corp. All Rights Reserved.       *
*******************************************************************************//*

LIBRARY        : alteralib; Rev 1.0; April 1994 
FUNCTION       : D-TYPE POSITIVE-EDGE-TRIGGERED FLIP-FLOPS WITH PRESET, CLEAR 
TRUTHTABLE     : 

          ----------------------------
          D    CLK   CLRN  PREN   Q
          ----------------------------
                 _
          L    _/     H    H      L   
                 _
          H    _/     H    H      H  
                
          X     L     H    H      Qo 
          
          X     X     L    H      L

          X     X     H    L      H

          X     X     L    L     illegal 

          ----------------------------- 

REFERENCE      : Altera MAX+Plus II online help, component description
DESIGNER       : 
DATE GENERATED : April 1994 
DATE MODIFIED  : 

VERITOOL COMPATIBILITY : Verilog x.x, Veritime y.y

*/
`timescale 1ns / 100ps
module dff (q, d, clk, clrn, prn);
	parameter size =1;
	parameter cds_action = "ignore";
	input
		d,
		clrn,
		prn,
		clk;
	output
		q;

	PRIM_DFF
	  (q, d, clk, clrn, prn);
specify

	// Synthesis parameters

`ifdef SYNTH
	specparam Area = 1;
`endif


endspecify
endmodule



/******************************************************************************
* This Program is the Confidential and Proprietary product of Altera Corp.    *
* Any unauthorized use,  reproduction or transfer of this program is strictly *
* prohibited. Copyright (c)  1993  by Altera Corp. All Rights Reserved.       *
*******************************************************************************//*

LIBRARY        : alteralib; Rev 1.0; April 94 
FUNCTION       : D-TYPE POSITIVE-EDGE-TRIGGERED FLIP-FLOPS WITH PRESET, CLEAR 
TRUTHTABLE     :

          ----------------------------
          D    CLK   CLRN  PRN   Q
          ----------------------------
                 _
          L    _/     H    H      L
                 _
          H    _/     H    H      H

          X     L     H    H      Qo

          X     X     L    H      L

          X     X     H    L      H

          X     X     L    L     illegal

          ----------------------------

REFERENCE      : Altera MAX+Plus II online help, component description
DESIGNER       : 
DATE GENERATED : April 1994 
DATE MODIFIED  : 

VERITOOL COMPATIBILITY : Verilog x.x, Veritime y.y

*/
`timescale 1ns / 100ps
primitive PRIM_DFF  (Q, D, CLK, CLRN, PRN);

    output Q;
    input  D, CLK, CLRN, PRN;
    reg    Q; 

    initial Q = 1'b0;

    // FUNCTION : POSITIVE EDGE TRIGGERED D FLIP-FLOP WITH ACTIVE LOW
    //            ASYNCHRONOUS SET AND CLEAR. ( Q OUTPUT UDP ).

    table
 
    //  D   CLK      CLRN  PRN  :   Qt  :   Qt+1

        1   (01)    1   1   :   ?   :   1;  // clocked data
        1   (01)    1   x   :   ?   :   1;  // pessimism

        1    ?      1   x   :   1   :   1;  // pessimism

        0    0      1   x   :   1   :   1;  // pessimism
        0    x      1 (?x)  :   1   :   1;  // pessimism
        0    1      1 (?x)  :   1   :   1;  // pessimism

        x    0      1   x   :   1   :   1;  // pessimism
        x    x      1 (?x)  :   1   :   1;  // pessimism
        x    1      1 (?x)  :   1   :   1;  // pessimism

        0   (01)    1   1   :   ?   :   0;  // clocked data
        0   (01)    x   1   :   ?   :   0;  // pessimism
 
        0    ?      x   1   :   0   :   0;  // pessimism

        1    0      x   1   :   0   :   0;  // pessimism
        1    x    (?x)  1   :   0   :   0;  // pessimism
        1    1    (?x)  1   :   0   :   0;  // pessimism

        x    0      x   1   :   0   :   0;  // pessimism
        x    x    (?x)  1   :   0   :   0;  // pessimism
        x    1    (?x)  1   :   0   :   0;  // pessimism

        1   (x1)    1   1   :   1   :   1;  // reducing pessimism
        0   (x1)    1   1   :   0   :   0;
        1   (0x)    1   1   :   1   :   1;
        0   (0x)    1   1   :   0   :   0;

        ?   ?       0   1   :   ?   :   0;  // asynchronous clear

        ?   ?       1   0   :   ?   :   1;  // asynchronous set

        ?   (?0)    1   1   :   ?   :   -;  // ignore falling clock
        ?   (1x)    1   1   :   ?   :   -;  // ignore falling clock
        *    ?      ?   ?   :   ?   :   -;  // ignore data edges 

        ?   ?     (?1)  1   :   ?   :   -;  // ignore the edges on 
        ?   ?       ?  (?1) :   ?   :   -;  //       set and clear 

    endtable

endprimitive
