/******************************************************************************
* This Program is the Confidential and Proprietary product of Altera Corp.    *
* Any unauthorized use,  reproduction or transfer of this program is strictly *
* prohibited. Copyright (c)  1993  by Altera Corp. All Rights Reserved.       *
*******************************************************************************//*

LIBRARY        : alteralib; Rev 1.0; February 93
FUNCTION       : D-TYPE POSITIVE-EDGE-TRIGGERED FLIP-FLOPS WITH PRESET, CLEAR & ENABLE 
TRUTHTABLE     : 

          -----------------------------------
           ENA   D    CLK   CLRN  PREN   Q
          -----------------------------------
                        _
           H     L    _/     H    H      L   
                        _
           H     H    _/     H    H      H  
                
           X     X     L     H    H      Qo 
          
           X     X     X     L    H      L

           X     X     X     H    L      H

           X     X     X     L    L     illegal 
                        
           L     X     X     H    H      Qo 

          -------------------------------- 

REFERENCE      : Altera MAX+Plus II online help, component description
DESIGNER       : AMI VIDER
DATE GENERATED : February 1993
DATE MODIFIED  : August 1993

VERITOOL COMPATIBILITY : Verilog x.x, Veritime y.y

*/

`timescale  1ns /  100ps
module dffe (q, ena, d, clk, clrn, prn);
	parameter size =1;
	parameter cds_action = "ignore";
	input
		d,
		clrn,
		prn,
		ena,
		clk;
	output
		q;

	PRIM_DFFE
	  (q, ena, d, clk, clrn, prn);
specify

	// Synthesis parameters

`ifdef SYNTH
	specparam Area = 1;
`endif


endspecify

endmodule



/******************************************************************************
* This Program is the Confidential and Proprietary product of Altera Corp.    *
* Any unauthorized use,  reproduction or transfer of this program is strictly *
* prohibited. Copyright (c)  1993  by Altera Corp. All Rights Reserved.       *
*******************************************************************************//*

LIBRARY        : alteralib; Rev 1.0; February 93
FUNCTION       : D-TYPE POSITIVE-EDGE-TRIGGERED FLIP-FLOPS WITH PRESET, CLEAR & ENABLE 
TRUTHTABLE     : 

          -----------------------------------
           ENA   D    CLK   CLRN  PREN   Q
          -----------------------------------
                        _
           H     L    _/     H    H      L   
                        _
           H     H    _/     H    H      H  
                
           X     X     L     H    H      Qo 
          
           X     X     X     L    H      L

           X     X     X     H    L      H

           X     X     X     L    L     illegal 
                        
           L     X     X     H    H      Qo 

          -------------------------------- 

REFERENCE      : Altera MAX+Plus II online help, component description
DESIGNER       : AMI VIDER
DATE GENERATED : February 1993
DATE MODIFIED  : August 1993

VERITOOL COMPATIBILITY : Verilog x.x, Veritime y.y

*/

`timescale  1ns /  100ps
primitive PRIM_DFFE(Q, ENA, D, CLK, CLRN, PRN);
    output 
         Q;
    input
         D,
         CLRN,
	     PRN,
         ENA,
         CLK;
    reg Q; 


    table
 
    //  ENA  D   CLK   CLRN PRN  :   Qt  :   Qt+1

       (01)  ?    ?      1   1   :   ?   :   -;  // pessimism
         1   1   (01)    1   1   :   ?   :   1;  // clocked data
         1   1   (01)    1   x   :   ?   :   1;  // pessimism

         1   1    ?      1   x   :   1   :   1;  // pessimism

         1   0    0      1   x   :   1   :   1;  // pessimism
         1   0    x      1 (?x)  :   1   :   1;  // pessimism
         1   0    1      1 (?x)  :   1   :   1;  // pessimism

         1   x    0      1   x   :   1   :   1;  // pessimism
         1   x    x      1 (?x)  :   1   :   1;  // pessimism
         1   x    1      1 (?x)  :   1   :   1;  // pessimism

         1   0   (01)    1   1   :   ?   :   0;  // clocked data
         1   0   (01)    x   1   :   ?   :   0;  // pessimism
 
         1   0    ?      x   1   :   0   :   0;  // pessimism

         1   1    0      x   1   :   0   :   0;  // pessimism
         1   1    x    (?x)  1   :   0   :   0;  // pessimism
         1   1    1    (?x)  1   :   0   :   0;  // pessimism

         1   x    0      x   1   :   0   :   0;  // pessimism
         1   x    x    (?x)  1   :   0   :   0;  // pessimism
         1   x    1    (?x)  1   :   0   :   0;  // pessimism

         1   1   (x1)    1   1   :   1   :   1;  // reducing pessimism
         1   0   (x1)    1   1   :   0   :   0;
         1   1   (0x)    1   1   :   1   :   1;
         1   0   (0x)    1   1   :   0   :   0;

         ?   ?   ?       0   1   :   ?   :   0;  // asynchronous clear

         ?   ?   ?       1   0   :   ?   :   1;  // asynchronous set

         1   ?   (?0)    1   1   :   ?   :   -;  // ignore falling clock
         1   ?   (1x)    1   1   :   ?   :   -;  // ignore falling clock
         1   *    ?      ?   ?   :   ?   :   -;  // ignore data edges 

         1   ?   ?     (?1)  1   :   ?   :   -;  // ignore the edges on 
         1   ?   ?       ?  (?1) :   ?   :   -;  //       set and clear 

         0   ?   ?       1   1   :   ?   :   -;  //       set and clear 

    endtable

endprimitive



